[QGIS Commit] r15199 - in trunk/qgis/src: app ui

svn_qgis at osgeo.org svn_qgis at osgeo.org
Fri Feb 18 10:18:41 EST 2011


Author: timlinux
Date: 2011-02-18 07:18:41 -0800 (Fri, 18 Feb 2011)
New Revision: 15199

Modified:
   trunk/qgis/src/app/CMakeLists.txt
   trunk/qgis/src/app/qgisapp.cpp
   trunk/qgis/src/app/qgsoptions.cpp
   trunk/qgis/src/app/qgstipfactory.cpp
   trunk/qgis/src/app/qgstipfactory.h
   trunk/qgis/src/ui/qgsoptionsbase.ui
   trunk/qgis/src/ui/qgstipguibase.ui
Log:
[FEATURE] Not sure how we coped without this till now...we now have a tip presented at startup. You can en/disable tips in the options panel. To contribute more tips, please add them to src/app/qgstipfactory.cpp

Modified: trunk/qgis/src/app/CMakeLists.txt
===================================================================
--- trunk/qgis/src/app/CMakeLists.txt	2011-02-18 15:18:10 UTC (rev 15198)
+++ trunk/qgis/src/app/CMakeLists.txt	2011-02-18 15:18:41 UTC (rev 15199)
@@ -87,6 +87,8 @@
   qgssnappingdialog.cpp
   qgsundowidget.cpp
   qgstilescalewidget.cpp
+  qgstipgui.cpp
+  qgstipfactory.cpp
   qgsuniquevaluedialog.cpp
   qgsvectorlayerproperties.cpp
   qgsquerybuilder.cpp
@@ -144,9 +146,7 @@
   qgisapp.h
   qgisappinterface.h
   qgsabout.h
-  qgssponsors.h
   qgsaddattrdialog.h
-  qgsdisplayangle.h
   qgsaddjoindialog.h
   qgsannotationwidget.h
   qgsattributeactiondialog.h
@@ -154,67 +154,72 @@
   qgsattributetypedialog.h
   qgsattributetypeloaddialog.h
   qgsbookmarks.h
+  qgsconfigureshortcutsdialog.h
   qgscontinuouscolordialog.h
-  qgsconfigureshortcutsdialog.h
   qgscustomprojectiondialog.h
+  qgsdbtablemodel.h
   qgsdelattrdialog.h
+  qgsdisplayangle.h
+  qgsfeatureaction.h
   qgsfieldcalculator.h
   qgsformannotationdialog.h
-  qgslabelinggui.h
-  qgslabelengineconfigdialog.h
-  qgsmaptoolmeasureangle.h
-  qgsnewvectorlayerdialog.h
   qgsgraduatedsymboldialog.h
   qgshelpviewer.h
   qgsidentifyresults.h
-  qgsfeatureaction.h
   qgslabeldialog.h
+  qgslabelengineconfigdialog.h
+  qgslabelinggui.h
   qgslabelpropertydialog.h
   qgsmanageconnectionsdialog.h
-  qgsmaptoolidentify.h
-  qgsmaptoolsplitfeatures.h
-  qgsmaptoolvertexedit.h
   qgsmaptooladdfeature.h
   qgsmaptooladdisland.h
   qgsmaptooladdring.h
+  qgsmaptooladdvertex.h
+  qgsmaptoolchangelabelproperties.h
+  qgsmaptooldeletepart.h
+  qgsmaptooldeletering.h
+  qgsmaptooldeletevertex.h
+  qgsmaptoolidentify.h
+  qgsmaptoolmeasureangle.h
   qgsmaptoolmovefeature.h
   qgsmaptoolmovelabel.h
+  qgsmaptoolmovevertex.h
   qgsmaptoolnodetool.h
   qgsmaptoolreshape.h
   qgsmaptoolrotatelabel.h
   qgsmaptoolrotatepointsymbols.h
+  qgsmaptoolselectfreehand.h
   qgsmaptoolselect.h
-  qgsmaptoolselectrectangle.h
-  qgsmaptoolselectfreehand.h
   qgsmaptoolselectpolygon.h
   qgsmaptoolselectradius.h
-  qgsmaptooladdvertex.h
-  qgsmaptoolchangelabelproperties.h
-  qgsmaptooldeletering.h
-  qgsmaptooldeletepart.h
-  qgsmaptooldeletevertex.h
-  qgsmaptoolmovevertex.h
+  qgsmaptoolselectrectangle.h
   qgsmaptoolsimplify.h
+  qgsmaptoolsplitfeatures.h
+  qgsmaptoolvertexedit.h
+  qgsmeasuredialog.h
   qgsmeasuretool.h
-  qgsmeasuredialog.h
   qgsmergeattributesdialog.h
   qgsnewhttpconnection.h
+  qgsnewvectorlayerdialog.h
   qgsoptions.h
   qgspastetransformations.h
   qgspluginmanager.h
   qgsprojectproperties.h
+  qgsquerybuilder.h
   qgsrastercalcdialog.h
   qgsrasterlayerproperties.h
-  qgstextannotationdialog.h
-  qgswmssourceselect.h
   qgssinglesymboldialog.h
   qgssnappingdialog.h
+  qgssponsors.h
+  qgstextannotationdialog.h
+  qgstilescalewidget.h
+  qgstip.h
+  qgstipgui.h
+  qgstipfactory.h
+  qgsundowidget.h
   qgsuniquevaluedialog.h
   qgsvectorlayerproperties.h
-  qgsdbtablemodel.h
-  qgsundowidget.h
-  qgstilescalewidget.h
-  qgsquerybuilder.h
+  qgswmssourceselect.h
 
   composer/qgsattributeselectiondialog.h
   composer/qgscomposer.h

Modified: trunk/qgis/src/app/qgisapp.cpp
===================================================================
--- trunk/qgis/src/app/qgisapp.cpp	2011-02-18 15:18:10 UTC (rev 15198)
+++ trunk/qgis/src/app/qgisapp.cpp	2011-02-18 15:18:41 UTC (rev 15199)
@@ -156,6 +156,7 @@
 #include "qgssponsors.h"
 #include "qgstextannotationitem.h"
 #include "qgstilescalewidget.h"
+#include "qgstipgui.h"
 #include "qgsundowidget.h"
 #include "qgsvectordataprovider.h"
 #include "qgsvectorfilewriter.h"
@@ -532,16 +533,31 @@
   mPrevScreenModeMaximized = false;
   show();
   qApp->processEvents();
-  //finally show all the application settings as initialised above
 
-  QgsDebugMsg( "\n\n\nApplication Settings:\n--------------------------\n" );
-  QgsDebugMsg( QgsApplication::showSettings() );
-  QgsDebugMsg( "\n--------------------------\n\n\n" );
   mMapCanvas->freeze( false );
   mMapCanvas->clearExtentHistory(); // reset zoomnext/zoomlast
   mLastComposerId = 0;
   mLBL = new QgsPalLabeling();
   mMapCanvas->mapRenderer()->setLabelingEngine( mLBL );
+
+  // Show a nice tip of the day
+  QSettings settings;
+  if ( settings.value( "/qgis/showTips", 1 ).toBool() )
+  {
+    mSplash->hide();
+    QgsTipGui myTip;
+    myTip.exec();
+  }
+  else
+  {
+    QgsDebugMsg( "Tips are disabled");
+  }
+
+  //finally show all the application settings as initialised above
+  QgsDebugMsg( "\n\n\nApplication Settings:\n--------------------------\n" );
+  QgsDebugMsg( QgsApplication::showSettings() );
+  QgsDebugMsg( "\n--------------------------\n\n\n" );
+
 } // QgisApp ctor
 
 

Modified: trunk/qgis/src/app/qgsoptions.cpp
===================================================================
--- trunk/qgis/src/app/qgsoptions.cpp	2011-02-18 15:18:10 UTC (rev 15198)
+++ trunk/qgis/src/app/qgsoptions.cpp	2011-02-18 15:18:41 UTC (rev 15199)
@@ -257,6 +257,7 @@
   chkAddedVisibility->setChecked( settings.value( "/qgis/new_layers_visible", true ).toBool() );
   cbxLegendClassifiers->setChecked( settings.value( "/qgis/showLegendClassifiers", false ).toBool() );
   cbxHideSplash->setChecked( settings.value( "/qgis/hideSplash", false ).toBool() );
+  cbxShowTips->setChecked( settings.value( "/qgis/showTips", true ).toBool() );
   cbxAttributeTableDocked->setChecked( settings.value( "/qgis/dockAttributeTable", false ).toBool() );
   cbxIdentifyResultsDocked->setChecked( settings.value( "/qgis/dockIdentifyResults", false ).toBool() );
   cbxSnappingOptionsDocked->setChecked( settings.value( "/qgis/dockSnapping", false ).toBool() );
@@ -527,6 +528,7 @@
   settings.setValue( "/Map/identifyRadius", spinBoxIdentifyValue->value() );
   settings.setValue( "/qgis/showLegendClassifiers", cbxLegendClassifiers->isChecked() );
   settings.setValue( "/qgis/hideSplash", cbxHideSplash->isChecked() );
+  settings.setValue( "/qgis/showTips", cbxShowTips->isChecked() );
   settings.setValue( "/qgis/dockAttributeTable", cbxAttributeTableDocked->isChecked() );
   settings.setValue( "/qgis/attributeTableBehaviour", cmbAttrTableBehaviour->currentIndex() );
   settings.setValue( "/qgis/dockIdentifyResults", cbxIdentifyResultsDocked->isChecked() );

Modified: trunk/qgis/src/app/qgstipfactory.cpp
===================================================================
--- trunk/qgis/src/app/qgstipfactory.cpp	2011-02-18 15:18:10 UTC (rev 15198)
+++ trunk/qgis/src/app/qgstipfactory.cpp	2011-02-18 15:18:41 UTC (rev 15199)
@@ -19,103 +19,74 @@
  ***************************************************************************/
 
 
-#include "omgtipfactory.h"
+#include "qgstipfactory.h"
 #include <QTime>
 //for rand & srand
 #include <cstdlib> 
 
 
-OmgTipFactory::OmgTipFactory() : QObject()
+QgsTipFactory::QgsTipFactory() : QObject()
 {
   // Im just doing this in a simple way so 
   // its easy for translators...later
   // it its worth the time Ill move this data
   // into a sqlite database...
-  OmgTip myTip;
-  myTip.setTitle(tr("openModeller is open source"));
-  myTip.setContent(tr("openModeller is open source software."
+  QgsTip myTip;
+  myTip.setTitle(tr("Quantum GIS is open source"));
+  myTip.setContent(tr("Quantum GIS is open source software."
         " This means that the software source code can be freely viewed "
         " and modified. The GPL places a restriction that any modifications "
         " you make must be made available to the openModeller project, and "
         " that you can not create a new version of openModeller under a "
-        " 'closed source' license. Visit <a href=\"http://openModeller.sf.net\">"
-        " the openModeller home page (http://openModeller.sf.net)</a> for more"
+        " 'closed source' license. Visit <a href=\"http://qgis.org\">"
+        " the QGIS home page (http://qgis.org)</a> for more"
         " information."));
   addGenericTip(myTip);
   //
-  myTip.setTitle(tr("openModeller Publications"));
+  myTip.setTitle(tr("QGIS Publications"));
   myTip.setContent(tr("If you write a scientific paper or any other article"
-        " that refers to openModeller we would love to include your work"
-        " in the references section of "
-        " the openModeller home page (http://openModeller.sf.net).</a>"
+        " that refers to QGIS we would love to include your work"
+        " in the <a href=\"http://www.qgis.org/en/community/qgis-case-studies.html\">case studies section</a> of"
+        " the Quantum GIS home page (http://http://www.qgis.org/en/community/qgis-case-studies.html)."
         ));
   addGenericTip(myTip);
-  myTip.setTitle(tr("Become an openModeller Desktop translator"));
-  myTip.setContent(tr("Would you like to see openModeller Desktop"
+  myTip.setTitle(tr("Become an QGIS translator"));
+  myTip.setContent(tr("Would you like to see QGIS"
         " in your native language? We are looking for more translators"
         " and would appreciate your help! The translation process is "
         " fairly straight forward - instructions are available in the "
-        " resources section of "
-        " the openModeller home page (http://openModeller.sf.net).</a>"
+        " QGIS wiki"
+        " <a href=\"http://www.qgis.org/wiki/GUI_Translation\">translator's page (http://www.qgis.org/wiki/GUI_Translation).</a>"
         ));
   addGuiTip(myTip);
-  myTip.setTitle(tr("openModeller Mailing lists"));
-  myTip.setContent(tr("If you need help using openModeller Desktop"
-        " we have a mailing list where users help each other with issues"
-        " related to niche modelling and using openModeller Desktop."
-        " Details on how to subscribe are in the resources section of"
-        " the openModeller home page (http://openModeller.sf.net).</a>"
+  myTip.setTitle(tr("QGIS Mailing lists"));
+  myTip.setContent(tr("If you need help using QGIS"
+        " we have a 'users'  mailing list where users help each other with issues"
+        " related to using our sofware. We also have a 'developers' mailing list."
+        " for those wanting help and to discuss things relating the the QGIS code base."
+        " Details on how to subscribe are in the <a href=\"http://www.qgis.org/en/community/mailing-lists.html\">community section</a> of"
+        " the QGIS home page (http://www.qgis.org/en/community/mailing-lists.html)."
         ));
   addGuiTip(myTip);
-  myTip.setTitle(tr("Is it 'modelling' or 'modeling'?"));
-  myTip.setContent(tr("Both spellings are correct. For openModeller"
-        " we use the former spelling."
+  myTip.setTitle(tr("Is it 'QGIS' or 'Quantum GIS'?"));
+  myTip.setContent(tr("Both are correct. For articles we suggest you write 'Quantum GIS (QGIS) is ....'"
+        " and then refer to it as QGIS thereafter."
         ));
   addGenericTip(myTip);
-  myTip.setTitle(tr("How do I refer to openModeller?"));
-  myTip.setContent(tr("openModeller is spelled with a lower case"
-        " 'o' at the start of the word - even if its the beginning"
-        " of a sentance. We have various subprojects of the openModeller "
+  myTip.setTitle(tr("How do I refer to Quantum GIS?"));
+  myTip.setContent(tr("QGIS is spelled in all caps."
+        " We have various subprojects of the QGIS project "
         " project and it will help to avoid confusion if you refer to each by"
         " its name:"
         "<ul>"
-        "<li>openModeller Library - this is the C++ library that contains"
-        " the core logic for carrying out niche modelling"
-        "<li>openModeller Console - these are a collection of command"
-        " line tools that allow you to run niche models from a unix or"
-        " DOS shell, or from a scripting environment."
-        "<li>openModeller Web Service - The openModeller Web Service"
-        " allows for remote execution of niche models."
-        "<li>openModeller Desktop - the openModeller Desktop provides"
-        " a graphical user interface for the openModeller Library. It"
-        " also includes the capability to run models using the"
-        " openModeller Web Service (though this is still considered"
-        " experimental)."
+        "<li>QGIS Library - this is the C++ library that contains"
+        " the core logic that is used to build the QGIS user interface and other applications.</li>"
+        "<li>QGIS Application - this is the desktop application that you know and love so much :-).</li>"
+        "<li>QGIS Mapserver - this is a server-side application based on the QGIS Library"
+        " that will serve up your .qgs projects using the WMS protocol.</li>"
         "</ul>"
         ));
   addGenericTip(myTip);
-  myTip.setTitle(tr("How can I improve model execution times?"));
-  myTip.setContent(tr("Model processing time is typically determined by"
-        "<ul>"
-        "<li>the algorithm you select,</li>"
-        "<li>the number, extents and spatial resolution of your format and environmental layers,</li>" 
-        "<li>the number of cells excluded by your mask (if any),</li>"
-        "<li>in some cases the number of presence and absence points (e.g. distance algs),</li>"
-        "<li>the speed of the computer the model is running on (CPU, disk access etc).</li>"
-        "</ul>"
-        "So if you want to improve model processing times you need to adjust "
-        "one of these variables. One thing noticed quite commonly is that people "
-        "use extremely high resolution datasets that often carry little "
-        "additional information over lower resolution equivalents. For example "
-        "interpolating widely dispersed weather station data to produce a 50cm "
-        "raster probably carries little additional value over for example using "
-        "10m2 pixels.<br>"
-        "Another area of performance improvement you can look at is "
-        "preselecting environmental variables using techniques such as Chi "
-        "Square test. Future versions of openModeller will integrate the ability "
-        "to do this type of preselection."
-        ));
-  addGenericTip(myTip);
   /* Template for adding more tips
   myTip.setTitle(tr(""));
   myTip.setContent(tr(""
@@ -124,52 +95,52 @@
   */
 }
 
-OmgTipFactory::~OmgTipFactory()
+QgsTipFactory::~QgsTipFactory()
 {
 
 }
 //private helper method
-void OmgTipFactory::addGuiTip(OmgTip theTip)
+void QgsTipFactory::addGuiTip(QgsTip theTip)
 {
   mGuiTips << theTip;
   mAllTips << theTip;
 }
 //private helper method
-void OmgTipFactory::addGenericTip(OmgTip theTip)
+void QgsTipFactory::addGenericTip(QgsTip theTip)
 {
   mGenericTips << theTip;
   mAllTips << theTip;
 }
-OmgTip OmgTipFactory::getTip()
+QgsTip QgsTipFactory::getTip()
 {
   srand(QTime::currentTime().msec());
   int myRand = rand();
   int myValue = static_cast<int> (myRand % mAllTips.count()); //range [0,(count-1)]
-  OmgTip myTip = mAllTips.at(myValue);
+  QgsTip myTip = mAllTips.at(myValue);
   return myTip;
 }
-OmgTip OmgTipFactory::getTip(int thePosition)
+QgsTip QgsTipFactory::getTip(int thePosition)
 {
-  OmgTip myTip = mAllTips.at(thePosition);
+  QgsTip myTip = mAllTips.at(thePosition);
   return myTip;
 }
-OmgTip OmgTipFactory::getGenericTip()
+QgsTip QgsTipFactory::getGenericTip()
 {
   srand(QTime::currentTime().msec());
   int myRand = rand();
   int myValue = static_cast<int> (myRand % mGenericTips.count()); //range [0,(count-1)]
-  OmgTip myTip = mGenericTips.at(myValue);
+  QgsTip myTip = mGenericTips.at(myValue);
   return myTip;
 }
-OmgTip OmgTipFactory::getGuiTip()
+QgsTip QgsTipFactory::getGuiTip()
 {
   srand(QTime::currentTime().msec());
   int myRand = rand();
   int myValue = static_cast<int> (myRand % mGuiTips.count()); //range [0,(count-1)]
-  OmgTip myTip = mGuiTips.at(myValue);
+  QgsTip myTip = mGuiTips.at(myValue);
   return myTip;
 }
-int OmgTipFactory::randomNumber(int theMax)
+int QgsTipFactory::randomNumber(int theMax)
 {
   return 0;
 }

Modified: trunk/qgis/src/app/qgstipfactory.h
===================================================================
--- trunk/qgis/src/ui/qgsoptionsbase.ui	2011-02-18 15:18:10 UTC (rev 15198)
+++ trunk/qgis/src/ui/qgsoptionsbase.ui	2011-02-18 15:18:41 UTC (rev 15199)
@@ -59,7 +59,7 @@
           <property name="geometry">
            <rect>
             <x>0</x>
-            <y>0</y>
+            <y>-155</y>
             <width>746</width>
             <height>640</height>
            </rect>
@@ -277,6 +277,13 @@
                </widget>
               </item>
               <item>
+               <widget class="QCheckBox" name="cbxShowTips">
+                <property name="text">
+                 <string>Show tips at start up</string>
+                </property>
+               </widget>
+              </item>
+              <item>
                <widget class="QCheckBox" name="cbxIdentifyResultsDocked">
                 <property name="text">
                  <string>Open identify results in a dock window (QGIS restart required)</string>
@@ -409,7 +416,7 @@
             <x>0</x>
             <y>0</y>
             <width>746</width>
-            <height>479</height>
+            <height>466</height>
            </rect>
           </property>
           <layout class="QGridLayout" name="gridLayout_8">
@@ -580,7 +587,7 @@
             <x>0</x>
             <y>0</y>
             <width>746</width>
-            <height>500</height>
+            <height>480</height>
            </rect>
           </property>
           <layout class="QGridLayout" name="gridLayout_4">
@@ -934,8 +941,8 @@
            <rect>
             <x>0</x>
             <y>0</y>
-            <width>746</width>
-            <height>462</height>
+            <width>762</width>
+            <height>458</height>
            </rect>
           </property>
           <layout class="QGridLayout" name="gridLayout_13">
@@ -1265,7 +1272,7 @@
             <x>0</x>
             <y>0</y>
             <width>746</width>
-            <height>531</height>
+            <height>527</height>
            </rect>
           </property>
           <layout class="QGridLayout" name="gridLayout_15">
@@ -1361,7 +1368,7 @@
             <x>0</x>
             <y>0</y>
             <width>746</width>
-            <height>552</height>
+            <height>545</height>
            </rect>
           </property>
           <layout class="QGridLayout" name="gridLayout_17">
@@ -1452,7 +1459,7 @@
             <x>0</x>
             <y>0</y>
             <width>746</width>
-            <height>548</height>
+            <height>531</height>
            </rect>
           </property>
           <layout class="QGridLayout" name="gridLayout_20">

Modified: trunk/qgis/src/ui/qgstipguibase.ui
===================================================================
--- trunk/qgis/src/ui/qgstipguibase.ui	2011-02-18 15:18:10 UTC (rev 15198)
+++ trunk/qgis/src/ui/qgstipguibase.ui	2011-02-18 15:18:41 UTC (rev 15199)
@@ -21,7 +21,20 @@
      </property>
     </widget>
    </item>
-   <item row="0" column="1" colspan="2">
+   <item row="0" column="1">
+    <widget class="QLabel" name="lblTitle">
+     <property name="styleSheet">
+      <string notr="true">font-weight: bold; </string>
+     </property>
+     <property name="text">
+      <string>Tip Title goes here</string>
+     </property>
+     <property name="textFormat">
+      <enum>Qt::PlainText</enum>
+     </property>
+    </widget>
+   </item>
+   <item row="1" column="1">
     <widget class="QTextBrowser" name="txtTip">
      <property name="sizePolicy">
       <sizepolicy hsizetype="Expanding" vsizetype="Expanding">
@@ -41,14 +54,14 @@
      </property>
     </widget>
    </item>
-   <item row="1" column="1" colspan="2">
-    <widget class="QCheckBox" name="checkBox">
+   <item row="2" column="1">
+    <widget class="QCheckBox" name="cbxDisableTips">
      <property name="text">
       <string>I've had enough tips, don't show this on start up any more!</string>
      </property>
     </widget>
    </item>
-   <item row="2" column="2">
+   <item row="3" column="1">
     <widget class="QDialogButtonBox" name="buttonBox">
      <property name="orientation">
       <enum>Qt::Horizontal</enum>



More information about the QGIS-commit mailing list
--- trunk/qgis/src/app/qgstipfactory.h	2011-02-18 15:18:10 UTC (rev 15198)
+++ trunk/qgis/src/app/qgstipfactory.h	2011-02-18 15:18:41 UTC (rev 15199)
@@ -18,57 +18,57 @@
  *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
  ***************************************************************************/
 
-#ifndef OMGTIPFACTORY
-#define OMGTIPFACTORY
+#ifndef QGSTIPFACTORY
+#define QGSTIPFACTORY
 
-#include "omgtip.h"
+#include "qgstip.h"
 #include <QList>
 
-/** \ingroup lib
+/** \ingroup app
 * \brief A factory class to serve up tips to the user.
 * Tips can be generic, in which case they make no mention of
 * gui dialogs etc, or gui-secific in which case they may allude
 * to features of the graphical user interface.
 * @see also OmgTipOfTheDay, OmgTip
 */
 
-class OMG_LIB_EXPORT OmgTipFactory : public QObject 
+class QgsTipFactory : public QObject 
 {
   Q_OBJECT; //used for tr() so we dont need to do QObject::tr()
   public:
     /** Constructor */
-    OmgTipFactory();
+    QgsTipFactory();
     /** Destructor */
-    ~OmgTipFactory();
+    ~QgsTipFactory();
     /** Get a random tip (generic or gui-centric)
      * @return An OmgTip containing the tip
      */
-    OmgTip getTip();
+    QgsTip getTip();
     /** Get a specific tip (generic or gui-centric).
      * @param thePosition The tip returned will be based on the 
      *        number passed in as thePosition. If the
      *        position is invalid, an empty string will be 
      *        returned.
      * @return An OmgTip containing the tip
      */
-    OmgTip getTip(int thePosition);
+    QgsTip getTip(int thePosition);
     /** Get a random generic tip
      * @return An OmgTip containing the tip
      */
-    OmgTip getGenericTip();
+    QgsTip getGenericTip();
     /** Get a random gui-centric tip
      * @return An OmgTip  containing the tip
      */
-    OmgTip getGuiTip();
+    QgsTip getGuiTip();
 
   private:
-    void addGenericTip(OmgTip);
-    void addGuiTip(OmgTip);
+    void addGenericTip(QgsTip);
+    void addGuiTip(QgsTip);
     int randomNumber(int theMax);
     //@TODO move tipts into a sqlite db
-    QList <OmgTip> mGenericTips;
-    QList <OmgTip> mGuiTips;
-    QList <OmgTip> mAllTips;
+    QList <QgsTip> mGenericTips;
+    QList <QgsTip> mGuiTips;
+    QList <QgsTip> mAllTips;
 };
-#endif //OMGTIPFACTORY
+#endif //QGSTIPFACTORY
 
@@ -18,57 +18,57 @@
 * gui dialogs etc, or gui-secific in which case they may allude
 * to features of the graphical user interface.
-* @see also OmgTipOfTheDay, OmgTip
+* @see also QgsTipOfTheDay, QgsTip
 */
 
@@ -18,57 +18,57 @@
     /** Get a random tip (generic or gui-centric)
-     * @return An OmgTip containing the tip
+     * @return An QgsTip containing the tip
      */
@@ -18,57 +18,57 @@
      *        position is invalid, an empty string will be 
      *        returned.
-     * @return An OmgTip containing the tip
+     * @return An QgsTip containing the tip
      */
@@ -18,57 +18,57 @@
     /** Get a random generic tip
-     * @return An OmgTip containing the tip
+     * @return An QgsTip containing the tip
      */
@@ -18,57 +18,57 @@
     /** Get a random gui-centric tip
-     * @return An OmgTip  containing the tip
+     * @return An QgsTip  containing the tip
      */

Modified: trunk/qgis/src/ui/qgsoptionsbase.ui
===================================================================